@@ -36,7 +36,8 @@ use anyhow::{bail, Result};
 use providers::{
     clojure::ClojureProvider, cobol::CobolProvider, crystal::CrystalProvider,
     csharp::CSharpProvider, dart::DartProvider, deno::DenoProvider, elixir::ElixirProvider,
-    fsharp::FSharpProvider, go::GolangProvider, haskell::HaskellStackProvider, java::JavaProvider,
+    fsharp::FSharpProvider, gleam::GleamProvider, go::GolangProvider,
+    haskell::HaskellStackProvider, java::JavaProvider, lunatic::LunaticProvider,
     node::NodeProvider, php::PhpProvider, python::PythonProvider, ruby::RubyProvider,
     rust::RustProvider, scala::ScalaProvider, staticfile::StaticfileProvider, swift::SwiftProvider,
     zig::ZigProvider, Provider,
@@ -47,6 +48,7 @@ mod chain;
 pub mod nixpacks;
 pub mod providers;
 
+/// Supplies all currently-defined providers to build plan generators and image builders.
 pub fn get_providers() -> &'static [&'static (dyn Provider)] {
     &[
         &CrystalProvider {},
@@ -56,9 +58,11 @@ pub fn get_providers() -> &'static [&'static (dyn Provider)] {
         &DenoProvider {},
         &FSharpProvider {},
         &ClojureProvider {},
+        &GleamProvider {},
         &GolangProvider {},
         &HaskellStackProvider {},
         &JavaProvider {},
+        &LunaticProvider {},
         &ScalaProvider {},
         &PhpProvider {},
         &RubyProvider {},
@@ -72,6 +76,7 @@ pub fn get_providers() -> &'static [&'static (dyn Provider)] {
     ]
 }
 
+/// Produces a build plan for the project based on environment variables and CLI options.
 pub fn generate_build_plan(
     path: &str,
     envs: Vec<&str>,
@@ -86,6 +91,7 @@ pub fn generate_build_plan(
     Ok(plan.0)
 }
 
+/// Get all specified and detected providers for a project.
 pub fn get_plan_providers(
     path: &str,
     envs: Vec<&str>,
@@ -99,6 +105,7 @@ pub fn get_plan_providers(
     generator.get_plan_providers(&app, &environment)
 }
 
+/// Builds a Docker image based on environment data and build options from config files or existing build plans.
 pub async fn create_docker_image(
     path: &str,
     envs: Vec<&str>,
