@@ -9,9 +9,11 @@ pub mod dart;
 pub mod deno;
 pub mod elixir;
 pub mod fsharp;
+pub mod gleam;
 pub mod go;
 pub mod haskell;
 pub mod java;
+pub mod lunatic;
 pub mod node;
 pub mod php;
 pub mod procfile;
