@@ -20,7 +20,9 @@ use super::{Provider, ProviderMetadata};
 
 const DEFAULT_PYTHON_PKG_NAME: &str = "python38";
 const POETRY_VERSION: &str = "1.3.1";
+const PDM_VERSION: &str = "2.7.4";
 const PIP_CACHE_DIR: &str = "/root/.cache/pip";
+const PDM_CACHE_DIR: &str = "/root/.cache/pdm";
 const DEFAULT_POETRY_PYTHON_PKG_NAME: &str = "python310";
 
 pub struct PythonProvider {}
@@ -42,11 +44,13 @@ impl Provider for PythonProvider {
         let is_django = PythonProvider::is_django(app, env)?;
         let is_using_postgres = PythonProvider::is_using_postgres(app, env)?;
         let is_poetry = app.includes_file("poetry.lock");
+        let is_pdm = app.includes_file("pdm.lock");
 
         Ok(ProviderMetadata::from(vec![
             (is_django, "django"),
             (is_using_postgres, "postgres"),
             (is_poetry, "poetry"),
+            (is_pdm, "pdm"),
         ]))
     }
 
@@ -75,6 +79,13 @@ impl Provider for PythonProvider {
             )]));
         }
 
+        if app.includes_file("pdm.lock") {
+            plan.add_variables(EnvironmentVariables::from([(
+                "NIXPACKS_PDM_VERSION".to_string(),
+                PDM_VERSION.to_string(),
+            )]));
+        }
+
         Ok(Some(plan))
     }
 }
@@ -163,6 +174,18 @@ impl PythonProvider {
 
                 install_phase.add_cache_directory(PIP_CACHE_DIR.to_string());
 
+                return Ok(Some(install_phase));
+            } else if app.includes_file("pdm.lock") {
+                let install_pdm = "pip install pdm==$NIXPACKS_PDM_VERSION".to_string();
+                let mut install_phase = Phase::install(Some(format!(
+                    "{create_env} && {activate_env} && {install_pdm} && pdm install --prod"
+                )));
+
+                install_phase.add_path(format!("{env_loc}/bin"));
+
+                install_phase.add_cache_directory(PIP_CACHE_DIR.to_string());
+                install_phase.add_cache_directory(PDM_CACHE_DIR.to_string());
+
                 return Ok(Some(install_phase));
             }
             let mut install_phase = Phase::install(Some(format!(
