@@ -657,6 +657,13 @@ async fn test_python_poetry() {
     assert!(output.contains("Hello from Python-Poetry"));
 }
 
+#[tokio::test]
+async fn test_python_pdm() {
+    let name = simple_build("./examples/python-pdm").await;
+    let output = run_image(&name, None).await;
+    assert!(output.contains("Hello from Python-PDM"));
+}
+
 #[tokio::test]
 async fn test_python_numpy() {
     let name = simple_build("./examples/python-numpy").await;
